@@ -50,6 +50,7 @@ class ImageData(DataClassJsonMixin):
   job_id: typing.Optional[str] = None
   image_bytes: typing.Optional[bytearray] = None
   creation_time: datetime = datetime.utcnow()
+  is_protected: typing.Optional[bool] = None
 
 
 @dataclass
@@ -81,6 +82,7 @@ class Job(DataClassJsonMixin):
   ddim_steps: int = 50
   scale: float = 7.5
 
+  user_original_prompt: typing.Optional[str] = None
   negative_prompt: typing.Optional[str] = None
   text2image_params: typing.Optional[Text2ImageParams] = None
   image2image_params: typing.Optional[Image2ImageParams] = None
@@ -92,6 +94,10 @@ class Job(DataClassJsonMixin):
   rating: typing.Optional[int] = None
   ip_address: typing.Optional[str] = None
 
+  app_version: typing.Optional[str] = None
+  device: typing.Optional[str] = None
+  device_os: typing.Optional[str] = None
+
 @dataclass
 class FilterExample(DataClassJsonMixin):
   # primary key is filter_id + tags
